@@ -3,9 +3,9 @@ from __future__ import annotations
 import os
 import sys
 import typing as t
-from textwrap import indent
 
 from . import artist
+from . import config
 from .argparse import ParamType
 from .console import console
 from .parser import parse_docstring
@@ -139,7 +139,6 @@ class CommandLineInterface:
         }
     
     def run(self, func=None):
-        from . import config
         from .argparse import extract_command_name, parse_argv
         
         config.apply_changes()
@@ -185,8 +184,10 @@ class CommandLineInterface:
         # FIXME: we take '--help' as the most important option to check. the
         #   '--help' is the only global option for now.
         if not result['args'] and not result['kwargs']:
-            if self.commands[id(func)]['args'] \
-                    or self.commands[id(func)]['kwargs']:
+            if self.commands[id(func)]['args']:
+                # it means user is not providing sufficient arguments.
+                # instead of rasing an exception, we guide user to see the help
+                # message.
                 result['kwargs'][':help'] = True
         if result['kwargs'].get(':help'):
             self.show(func)
@@ -199,12 +200,11 @@ class CommandLineInterface:
                 # # for func_info in self.commands.values():
                 # #     self.show(func_info['func'])
         else:
-            self.exec(func, result['args'], result['kwargs'])
+            self.exec(func, result['args'].values(), result['kwargs'])
     
     def show(self, func):
         """
-        reference:
-            [lib:click]/core.py : BaseCommand.main()
+        reference: [lib:click/core.py : BaseCommand.main()]
         """
         is_group: bool
         has_args: bool
@@ -219,9 +219,9 @@ class CommandLineInterface:
                 artist.draw_title(
                     prog_name=_detect_program_name(),
                     command='<COMMAND>',
+                    options='[OPTIONS]',
                     arguments=None,
-                ),
-                justify='center'
+                ), justify='center'
             )
             
             console.print(
@@ -239,28 +239,45 @@ class CommandLineInterface:
             has_kwargs = bool(func_info['kwargs'])
             
             # experimental
-            if has_args and has_kwargs:
-                from .config import Dynamic
-                Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME = max((
-                    *map(len, (x['cname']
-                               for x in func_info['args'].values())),
-                    *map(len, (x['cname'].replace(',', ', ')
-                               for x in func_info['kwargs'].values())),
-                ))
-                # print(Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME, ':v')
+            if config.ALIGN_ARGS_AND_OPTS_FIELD_WIDTH:
+                if has_args and has_kwargs:
+                    config.Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME = max((
+                        *map(len, (x['cname']
+                                   for x in func_info['args'].values())),
+                        *map(len, (x['cname'].replace(',', ', ')
+                                   for x in func_info['kwargs'].values())),
+                    ))
+                    # print(Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME, ':v')
             
-            console.print(
-                artist.draw_title(
-                    prog_name=_detect_program_name(),
-                    command=func_info['cname'],
-                    arguments=tuple(
-                        v['cname'] for v in func_info['args'].values()
-                    ),
-                ),
-                justify='center'
-            )
-            if desc:
-                console.print(indent(desc, ' '))
+            from textwrap import indent
+            if (has_args or has_kwargs) or (not desc):
+                console.print(
+                    artist.draw_title(
+                        prog_name=_detect_program_name(),
+                        command=func_info['cname'],
+                        options='[OPTIONS]' if has_kwargs else None,
+                        arguments=tuple(
+                            v['cname'] for v in func_info['args'].values()
+                        ),
+                    ), justify='center'
+                )
+                if desc: console.print(indent(desc, ' '))
+            else:
+                # assert desc
+                console.print('\n'.join((
+                    '',
+                    indent(artist.draw_title(
+                        prog_name=_detect_program_name(),
+                        command=func_info['cname'],
+                        options='[OPTIONS]' if has_kwargs else None,
+                        arguments=tuple(
+                            v['cname'] for v in func_info['args'].values()
+                        ),
+                        serif_line=True,
+                    ), '    '),
+                    indent(f'[grey74]{desc}[/]', '    '),
+                    ''
+                )))
             
             if args := func_info['args']:
                 console.print(
@@ -324,6 +341,7 @@ class CommandLineInterface:
                     artist.draw_title(
                         prog_name=_detect_program_name(),
                         command='<COMMAND>',
+                        options='[OPTIONS]',
                         arguments=None,
                     )
                 )
@@ -343,25 +361,28 @@ class CommandLineInterface:
                 has_kwargs = bool(func_info['kwargs'])
                 
                 # experimental
-                if has_args and has_kwargs:
-                    from .config import Dynamic
-                    Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME = max((
-                        *map(len, (x['cname']
-                                   for x in func_info['args'].values())),
-                        *map(len, (x['cname'].replace(',', ', ')
-                                   for x in func_info['kwargs'].values())),
-                    ))
+                if config.ALIGN_ARGS_AND_OPTS_FIELD_WIDTH:
+                    if has_args and has_kwargs:
+                        config.Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME = max((
+                            *map(len, (x['cname']
+                                       for x in func_info['args'].values())),
+                            *map(len, (x['cname'].replace(',', ', ')
+                                       for x in func_info['kwargs'].values())),
+                        ))
+                        # print(Dynamic.PREFERRED_FIELD_WIDTH_OF_NAME, ':v')
                 
                 collect_renderables['title'] = Align.center(
                     artist.draw_title(
                         prog_name=_detect_program_name(),
                         command=func_info['cname'],
+                        options='[OPTIONS]' if has_kwargs else None,
                         arguments=tuple(
                             v['cname'] for v in func_info['args'].values()
                         ),
                     )
                 )
                 if desc:
+                    from textwrap import indent
                     collect_renderables['desc'] = indent(desc, ' ')
                 
                 if args := func_info['args']:
@@ -391,9 +412,10 @@ class CommandLineInterface:
                 collect_renderables['logo'] = Padding(
                     Align.right(
                         artist.post_logo(
-                            style='magenta' if is_group
-                            else 'white' if has_kwargs
-                            else 'blue'
+                            style='tan'
+                            # style='magenta' if is_group
+                            # else 'white' if has_kwargs
+                            # else 'blue'
                         ), style='bold'
                     ), (0, 1, 0, 0)
                 )
@@ -484,7 +506,7 @@ class CommandLineInterface:
         console.print(render())
     
     @staticmethod
-    def exec(func: t.Callable, args: t.Sequence, kwargs: dict):
+    def exec(func: t.Callable, args: t.Iterable, kwargs: dict):
         try:
             func(*args, **kwargs)
         except Exception:
@@ -495,7 +517,7 @@ def _detect_program_name() -> str:
     """
     determine the program name to be `python ...` or `python -m ...`.
     
-    source: ~/click/utils.py : _detect_program_name()
+    source: [lib:click/utrils.py : def _detect_program_name()]
     
     return:
         examples:
@@ -507,8 +529,13 @@ def _detect_program_name() -> str:
     path = sys.argv[0]
     name = os.path.splitext(os.path.basename(path))[0]
     
+    from .config import TITLE_HEAD_STYLE
+    head = 'python' if TITLE_HEAD_STYLE == 'fixed' else (
+        'py' if os.name == 'nt' else 'python3'
+    )
+    
     if getattr(main, '__package__', None) is None:
-        return f'python {name}.py'
+        return f'{head} {name}.py'
     elif (
             os.name == 'nt'
             and main.__package__ == ''
@@ -520,7 +547,8 @@ def _detect_program_name() -> str:
     py_module = t.cast(str, main.__package__)
     if name != '__main__':  # a submodule like 'example.cli'
         py_module = f'{py_module}.{name}'.lstrip('.')
-    return f'python -m {py_module}'
+    
+    return f'{head} -m {py_module}'
 
 
 cli = CommandLineInterface(name='argsense-cli')
